==> Sim.DiffProc_1.0.tar.gz: Sim.DiffProc/demo/sde.R <==
## 11/04/2010 03:08:42
## Guidoum Arsalane (PG-PS/USTHB)
## Stochastic Processes 
## Mathematical models


plot(0:20,0:20,type="n",xlab="",axes=F,ylab="",main=expression("Stochastic Processes":dX[t]==(alpha+beta*X[t])*dt+sigma*X[t]^gamma*dW[t]))
mtext("financial and actuarial models",line=0.4,cex=1.2,col="blue")
mtext("models",adj=0.05,line=-1.3,cex=1.2,col="red")
mtext("Expressions ",adj=0.5,line=-1.3,cex=1.2,col="red")
mtext(expression(alpha),adj=0.82,line=-1.3,cex=1.2,col="red")
mtext(expression(beta),adj=0.9,line=-1.3,cex=1.2,col="red")
mtext(expression(gamma),adj=0.98,line=-1.3,cex=1.2,col="red")
mtext("Merton(1973)",adj=0.02,line=-3,cex=1)
mtext("Vasicek(1977)",adj=0.02,line=-5,cex=1)
mtext("CIR SR(1985)",adj=0.02,line=-7,cex=1)
mtext("Brennan &",adj=0.02,line=-9,cex=1)
mtext("Schwartz(1980)",adj=0.02,line=-10,cex=1)
mtext("CEV",adj=0.02,line=-12,cex=1)
mtext("Dothan(1978)",adj=0.02,line=-14,cex=1)
mtext("CIR VR(1980)",adj=0.02,line=-16,cex=1)
mtext("Black & Scholes",adj=0.02,line=-18.4,cex=1)
mtext("Longstaff(1989)",adj=0.02,line=-20.4,cex=1)
mtext(expression(dX[t]==alpha*dt+sigma*dW[t]),line=-3,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*dW[t]),line=-5,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*sqrt(X[t])*dW[t]),line=-7,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*X[t]*dW[t]),line=-9.5,adj=0.5,cex=1)
mtext(expression(dX[t]==beta*X[t]*dt+sigma*X[t]^gamma*dW[t]),line=-12,adj=0.5,cex=1)
mtext(expression(dX[t]==sigma*X[t]*dW[t]),line=-14,adj=0.5,cex=1)
mtext(expression(dX[t]==sigma*X[t]^frac(3,2)*dW[t]),line=-16.3,adj=0.5,cex=1)
mtext(expression(dX[t]==beta*X[t]*dt+sigma*X[t]*dW[t]),line=-18.4,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*sqrt(X[t]))*dt+sigma*sqrt(X[t])*dW[t]),line=-20.4,adj=0.55,cex=1)
mtext(expression(0),adj=0.9,line=-2.7,cex=1)
mtext(expression(0),adj=0.98,line=-2.7,cex=1)
mtext(expression(0),adj=0.98,line=-4.7,cex=1)
mtext(expression(frac(1,2)),adj=0.98,line=-7.7,cex=1)
mtext(expression(1),adj=0.98,line=-9.3,cex=1)
mtext(expression(0),adj=0.82,line=-11.7,cex=1)
mtext(expression(0),adj=0.82,line=-13.8,cex=1)
mtext(expression(0),adj=0.9,line=-13.8,cex=1)
mtext(expression(1),adj=0.98,line=-13.8,cex=1)
mtext(expression(0),adj=0.82,line=-16,cex=1)
mtext(expression(0),adj=0.9,line=-16,cex=1)
mtext(expression(frac(3,2)),adj=0.98,line=-17,cex=1)
mtext(expression(0),adj=0.82,line=-18.4,cex=1)
mtext(expression(0),adj=0.82,line=-18.4,cex=1)
mtext(expression(1),adj=0.98,line=-18.4,cex=1)
mtext("**",adj=0.9,line=-20.4,cex=1)
mtext("**",adj=0.98,line=-20.4,cex=1)
mtext("**",adj=0.82,line=-20.4,cex=1)
abline(v=-0.7,col="blue",lwd=4)
abline(h=-0.8,col="blue",lwd=4)
abline(h=20.7,col="blue",lwd=4)
abline(v=20.8,col="blue",lwd=4)
abline(v=5.1,col="blue",lwd=3)
abline(v=15.7,col="blue",lwd=3)
abline(h=19,col="blue",lwd=3)
abline(v=17.2,col="blue",lwd=3)
abline(v=19,col="blue",lwd=3)
abline(h=17,col="blue",lwd=3)
abline(h=15.2,col="blue",lwd=3)
abline(h=12.5,col="blue",lwd=3)
abline(h=9.8,col="blue",lwd=3)
abline(h=7.5,col="blue",lwd=3)
abline(h=5.6,col="blue",lwd=3)
abline(h=3.0,col="blue",lwd=3)
abline(h=1.2,col="blue",lwd=3)
mtext(paste("USTHB,Faculty of Mathematics,Department of Probabilities and Statistics,Algeria",date()),
      side = 1, line = 4, adj = 0.5, cex = .66)

==> Sim.DiffProc_2.0.tar.gz: Sim.DiffProc/demo/sde.R <==
## 11/04/2010 03:08:42
## Guidoum Arsalane (PG-PS/USTHB)
## Stochastic Processes 
## Mathematical models


plot(0:20,0:20,type="n",xlab="",ylab="",axes=FALSE,main=expression("Stochastic Processes":dX[t]==(alpha+beta*X[t])*dt+sigma*X[t]^gamma*dW[t]))
mtext("financial and actuarial models",line=0.4,cex=1.2,col="blue")
mtext("models",adj=0.05,line=-1.3,cex=1.2,col="red")
mtext("Expressions ",adj=0.5,line=-1.3,cex=1.2,col="red")
mtext(expression(alpha),adj=0.82,line=-1.3,cex=1.2,col="red")
mtext(expression(beta),adj=0.9,line=-1.3,cex=1.2,col="red")
mtext(expression(gamma),adj=0.98,line=-1.3,cex=1.2,col="red")
mtext("Merton(1973)",adj=0.02,line=-3,cex=1)
mtext("Vasicek(1977)",adj=0.02,line=-5,cex=1)
mtext("CIR SR(1985)",adj=0.02,line=-7,cex=1)
mtext("Brennan &",adj=0.02,line=-9,cex=1)
mtext("Schwartz(1980)",adj=0.02,line=-10,cex=1)
mtext("CEV",adj=0.02,line=-12,cex=1)
mtext("Dothan(1978)",adj=0.02,line=-14,cex=1)
mtext("CIR VR(1980)",adj=0.02,line=-16,cex=1)
mtext("Black & Scholes",adj=0.02,line=-18.4,cex=1)
mtext("Longstaff(1989)",adj=0.02,line=-20.4,cex=1)
mtext(expression(dX[t]==alpha*dt+sigma*dW[t]),line=-3,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*dW[t]),line=-5,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*sqrt(X[t])*dW[t]),line=-7,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*X[t])*dt+sigma*X[t]*dW[t]),line=-9.5,adj=0.5,cex=1)
mtext(expression(dX[t]==beta*X[t]*dt+sigma*X[t]^gamma*dW[t]),line=-12,adj=0.5,cex=1)
mtext(expression(dX[t]==sigma*X[t]*dW[t]),line=-14,adj=0.5,cex=1)
mtext(expression(dX[t]==sigma*X[t]^frac(3,2)*dW[t]),line=-16.3,adj=0.5,cex=1)
mtext(expression(dX[t]==beta*X[t]*dt+sigma*X[t]*dW[t]),line=-18.4,adj=0.5,cex=1)
mtext(expression(dX[t]==(alpha+beta*sqrt(X[t]))*dt+sigma*sqrt(X[t])*dW[t]),line=-20.4,adj=0.55,cex=1)
mtext(expression(0),adj=0.9,line=-2.7,cex=1)
mtext(expression(0),adj=0.98,line=-2.7,cex=1)
mtext(expression(0),adj=0.98,line=-4.7,cex=1)
mtext(expression(frac(1,2)),adj=0.98,line=-7.7,cex=1)
mtext(expression(1),adj=0.98,line=-9.3,cex=1)
mtext(expression(0),adj=0.82,line=-11.7,cex=1)
mtext(expression(0),adj=0.82,line=-13.8,cex=1)
mtext(expression(0),adj=0.9,line=-13.8,cex=1)
mtext(expression(1),adj=0.98,line=-13.8,cex=1)
mtext(expression(0),adj=0.82,line=-16,cex=1)
mtext(expression(0),adj=0.9,line=-16,cex=1)
mtext(expression(frac(3,2)),adj=0.98,line=-17,cex=1)
mtext(expression(0),adj=0.82,line=-18.4,cex=1)
mtext(expression(0),adj=0.82,line=-18.4,cex=1)
mtext(expression(1),adj=0.98,line=-18.4,cex=1)
mtext("**",adj=0.9,line=-20.4,cex=1)
mtext("**",adj=0.98,line=-20.4,cex=1)
mtext("**",adj=0.82,line=-20.4,cex=1)
abline(v=-0.7,col="blue",lwd=4)
abline(h=-0.8,col="blue",lwd=4)
abline(h=20.7,col="blue",lwd=4)
abline(v=20.8,col="blue",lwd=4)
abline(v=5.1,col="blue",lwd=3)
abline(v=15.7,col="blue",lwd=3)
abline(h=19,col="blue",lwd=3)
abline(v=17.2,col="blue",lwd=3)
abline(v=19,col="blue",lwd=3)
abline(h=17,col="blue",lwd=3)
abline(h=15.2,col="blue",lwd=3)
abline(h=12.5,col="blue",lwd=3)
abline(h=9.8,col="blue",lwd=3)
abline(h=7.5,col="blue",lwd=3)
abline(h=5.6,col="blue",lwd=3)
abline(h=3.0,col="blue",lwd=3)
abline(h=1.2,col="blue",lwd=3)
mtext(paste("USTHB,Faculty of Mathematics,Department of Probabilities and Statistics,Algeria",date()),
      side = 1, line = 4, adj = 0.5, cex = .66)
